nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

PkcCfg

Struct PkcCfg 

#[repr(transparent)]
pub struct PkcCfg(pub u32);
Configuration register

Tuple Fields

0: u32

Implementations

Source

impl PkcCfg

pub const fn idleop(&self) -> bool

Idle operation feature not available in this version (flag is don’t care).

pub const fn set_idleop(&mut self, val: bool)

Idle operation feature not available in this version (flag is don’t care).

pub const fn rfu1(&self) -> bool

RFU

pub const fn set_rfu1(&mut self, val: bool)

RFU

pub const fn rfu2(&self) -> bool

RFU

pub const fn set_rfu2(&mut self, val: bool)

RFU

pub const fn clkrnd(&self) -> bool

Clock randomization feature not available in this version (flag is don’t care).

pub const fn set_clkrnd(&mut self, val: bool)

Clock randomization feature not available in this version (flag is don’t care).

pub const fn redmulnoise(&self) -> bool

Noise in reduced multiplier mode feature not available in this version (flag is don’t care).

pub const fn set_redmulnoise(&mut self, val: bool)

Noise in reduced multiplier mode feature not available in this version (flag is don’t care).

pub const fn rnddly(&self) -> u8

Random delay feature not available in this version (flag is don’t care).

pub const fn set_rnddly(&mut self, val: u8)

Random delay feature not available in this version (flag is don’t care).

pub const fn sbxnoise(&self) -> bool

Noise feature not available in this version (flag is don’t care).

pub const fn set_sbxnoise(&mut self, val: bool)

Noise feature not available in this version (flag is don’t care).

pub const fn alpnoise(&self) -> bool

Noise feature not available in this version (flag is don’t care).

pub const fn set_alpnoise(&mut self, val: bool)

Noise feature not available in this version (flag is don’t care).

pub const fn fmulnoise(&self) -> bool

Noise feature not available in this version (flag is don’t care).

pub const fn set_fmulnoise(&mut self, val: bool)

Noise feature not available in this version (flag is don’t care).