nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

PkcCtrl

Struct PkcCtrl 

#[repr(transparent)]
pub struct PkcCtrl(pub u32);
Control Register

Tuple Fields

0: u32

Implementations

Source

impl PkcCtrl

pub const fn reset(&self) -> bool

PKC reset control bit

pub const fn set_reset(&mut self, val: bool)

PKC reset control bit

pub const fn stop(&self) -> bool

Freeze PKC calculation

pub const fn set_stop(&mut self, val: bool)

Freeze PKC calculation

pub const fn god1(&self) -> bool

Control bit to start direct operation using parameter set 1

pub const fn set_god1(&mut self, val: bool)

Control bit to start direct operation using parameter set 1

pub const fn god2(&self) -> bool

Control bit to start direct operation using parameter set 2

pub const fn set_god2(&mut self, val: bool)

Control bit to start direct operation using parameter set 2

pub const fn gom1(&self) -> bool

Control bit to start MC pattern using parameter set 1

pub const fn set_gom1(&mut self, val: bool)

Control bit to start MC pattern using parameter set 1

pub const fn gom2(&self) -> bool

Control bit to start MC pattern using parameter set 2

pub const fn set_gom2(&mut self, val: bool)

Control bit to start MC pattern using parameter set 2

pub const fn gou(&self) -> bool

Control bit to start pipe operation

pub const fn set_gou(&mut self, val: bool)

Control bit to start pipe operation

pub const fn gf2conv(&self) -> bool

Convert to GF2 calculation modes

pub const fn set_gf2conv(&mut self, val: bool)

Convert to GF2 calculation modes

pub const fn clrcache(&self) -> bool

Clear universal pointer cache

pub const fn set_clrcache(&mut self, val: bool)

Clear universal pointer cache

pub const fn cache_en(&self) -> bool

Enable universal pointer cache

pub const fn set_cache_en(&mut self, val: bool)

Enable universal pointer cache

pub const fn redmul(&self) -> Redmul

Reduced multiplier mode

pub const fn set_redmul(&mut self, val: Redmul)

Reduced multiplier mode