nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

PkcZrptr1

Struct PkcZrptr1 

#[repr(transparent)]
pub struct PkcZrptr1(pub u32);
Z+R pointer register, parameter set 1

Tuple Fields

0: u32

Implementations

Source

impl PkcZrptr1

pub const fn zptr(&self) -> u16

Start address of Z operand in PKCRAM with byte granularity or constant for calculation modes using CONST

pub const fn set_zptr(&mut self, val: u16)

Start address of Z operand in PKCRAM with byte granularity or constant for calculation modes using CONST

pub const fn rptr(&self) -> u16

Start address of R result in PKCRAM with byte granularity

pub const fn set_rptr(&mut self, val: u16)

Start address of R result in PKCRAM with byte granularity