#[repr(transparent)]pub struct PkcCtrl(pub u32);Expand description
Control Register
Tuple Fields
0: u32Implementations
Sourceimpl PkcCtrl
impl PkcCtrl
Sourcepub const fn set_god1(&mut self, val: bool)
pub const fn set_god1(&mut self, val: bool)
Control bit to start direct operation using parameter set 1
Sourcepub const fn set_god2(&mut self, val: bool)
pub const fn set_god2(&mut self, val: bool)
Control bit to start direct operation using parameter set 2
Sourcepub const fn set_gom1(&mut self, val: bool)
pub const fn set_gom1(&mut self, val: bool)
Control bit to start MC pattern using parameter set 1
Sourcepub const fn set_gom2(&mut self, val: bool)
pub const fn set_gom2(&mut self, val: bool)
Control bit to start MC pattern using parameter set 2
Sourcepub const fn set_gf2conv(&mut self, val: bool)
pub const fn set_gf2conv(&mut self, val: bool)
Convert to GF2 calculation modes
Sourcepub const fn set_clrcache(&mut self, val: bool)
pub const fn set_clrcache(&mut self, val: bool)
Clear universal pointer cache
Sourcepub const fn set_cache_en(&mut self, val: bool)
pub const fn set_cache_en(&mut self, val: bool)
Enable universal pointer cache
Sourcepub const fn set_redmul(&mut self, val: Redmul)
pub const fn set_redmul(&mut self, val: Redmul)
Reduced multiplier mode